==> generator-workflow-onboarder-1.0.2.tgz: package/generators/app/index.js <==
"use strict";
const Generator = require("yeoman-generator");
const chalk = require("chalk");
const yosay = require("yosay");

module.exports = class extends Generator {
  prompting() {
    // Have Yeoman greet the user.
    this.log(
      yosay(
        `Welcome to the splendid ${chalk.red("generator-tats-poc")} generator!`
      )
    );

    const prompts = [
      {
        type: "confirm",
        name: "someAnswer",
        message: "Would you like to enable this option?",
        default: true
      }
    ];

    return this.prompt(prompts).then(props => {
      // To access props later use this.props.someAnswer;
      this.props = props;
    });
  }

  writing() {
    const scaffoldingFileName = [
      "readme.txt",
      ".github/dependabot.yml",
      ".github/markdown.links.config.json",
      ".github/pr-title-config.json",
      ".github/workflows/codeql.yml",
      ".github/workflows/lint-go.yaml",
      ".github/workflows/markdown-link-check.yml",
      ".github/workflows/aks-e2e-workflow.yml",
      ".github/workflows/dependency-review.yml",
      ".github/workflows/pr-e2e.yml",
      ".github/workflows/scorecard.yml",
      ".github/workflows/unit-tests.yml",
      ".github/workflows/create-gh-release.yml",
      ".github/workflows/publish-github-image.yml",
      ".github/workflows/publish-helm-chart.yml",
      ".github/workflows/publish-mcr-image.yml",
      "hack/go-install.sh",
      "pkg/first/test.go",
      // ".gitignore",
      "go.sum",
      "go.mod",
      "main.go",
      ".pre-commit-config.yaml",
      "Dockerfile",
      "Makefile",
      "goreleaser.yml",
      "LICENSE",
      ".golangci.yaml"
    ];

    if (this.props.someAnswer) {
      scaffoldingFileName.forEach(fileName => {
        this.fs.copy(
          this.templatePath(fileName),
          this.destinationPath(fileName)
        );
      });
    }
  }

  install() {
    // this.installDependencies();
  }
};

==> generator-workflow-onboarder-1.0.3.tgz: package/generators/app/index.js <==
"use strict";
const Generator = require("yeoman-generator");
const chalk = require("chalk");
const yosay = require("yosay");

module.exports = class extends Generator {
  prompting() {
    // Have Yeoman greet the user.
    this.log(
      yosay(
        `Welcome to the splendid ${chalk.red("generator-tats-poc")} generator!`
      )
    );

    const prompts = [
      {
        type: "confirm",
        name: "someAnswer",
        message: "Would you like to enable this option?",
        default: true
      }
    ];

    return this.prompt(prompts).then(props => {
      // To access props later use this.props.someAnswer;
      this.props = props;
    });
  }

  writing() {
    const scaffoldingFileName = [
      "readme.txt",
      ".github/dependabot.yml",
      ".github/markdown.links.config.json",
      ".github/pr-title-config.json",
      ".github/workflows/codeql.yml",
      ".github/workflows/lint-go.yaml",
      ".github/workflows/markdown-link-check.yml",
      ".github/workflows/aks-e2e-workflow.yml",
      ".github/workflows/dependency-review.yml",
      ".github/workflows/pr-e2e.yml",
      ".github/workflows/scorecard.yml",
      ".github/workflows/unit-test.yml",
      ".github/workflows/create-gh-release.yml",
      ".github/workflows/publish-github-image.yml",
      ".github/workflows/publish-helm-chart.yml",
      ".github/workflows/publish-mcr-image.yml",
      "hack/go-install.sh",
      "pkg/first/test.go",
      // ".gitignore",
      "go.sum",
      "go.mod",
      "main.go",
      ".pre-commit-config.yaml",
      "Dockerfile",
      "Makefile",
      "goreleaser.yml",
      "LICENSE",
      ".golangci.yaml"
    ];

    if (this.props.someAnswer) {
      scaffoldingFileName.forEach(fileName => {
        this.fs.copy(
          this.templatePath(fileName),
          this.destinationPath(fileName)
        );
      });
    }
  }

  install() {
    // this.installDependencies();
  }
};
